# Installation | Установка

## Windows
```
pip install async-qiwi
```

## Linux
```
pip3 install async-qiwi
```
![изображение](https://imgur.com/kFB0bd4.png)


# Information | Информация
Актуальная версия AsyncQiwi 0.1.0

## Methods | Фyнкции
```
Получение актуального баланса по нужной валюте
Получение номера телефона
Работа с Qiwi P2P Kassa
 ```